# pyrvo

pyrvo is a Python binding for [ORCA (Optimal Reciprocal Collision Avoidance) library](https://github.com/snape/RVO2). It provides a Python interface with similar API as original ORCA.

## Installation

### Build from source

```
git clone https://github.com/hanruihua/pyrvo.git
cd pyrvo
pip install -e .
```

### Install from PyPI

```
pip install pyrvo
```

## Example

```
python test/test_python/Circle_render.py
```

```
python test/test_python/Blocks_render.py
```

```
python test/test_python/Roadmap_render.py
```



